        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,11,12,16,17,18,19,20,25,26,28,29,30,31,33,34,35,39,40,42,45,48,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 23 <br>3,6,7,8,9,10,13,14,15,21,22,23,24,27,32,36,37,38,41,43,44,46,47';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,11,12,16,17,18,19,20,25,26,28,29,30,31,33,34,35,39,40,42,45,48,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 23 <br>3,6,7,8,9,10,13,14,15,21,22,23,24,27,32,36,37,38,41,43,44,46,47';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,11,12,16,17,18,19,20,25,26,28,29,30,31,33,34,35,39,40,42,45,48,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 23 <br>3,6,7,8,9,10,13,14,15,21,22,23,24,27,32,36,37,38,41,43,44,46,47';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,11,12,16,17,18,19,20,25,26,28,29,30,31,33,34,35,39,40,42,45,48,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 23 <br>3,6,7,8,9,10,13,14,15,21,22,23,24,27,32,36,37,38,41,43,44,46,47';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>1</strong> representante: <strong>34</strong> miembros: 28 <strong>control</strong><br>0,1,2,4,5,11,12,16,17,18,19,20,25,26,28,29,30,31,33,34,35,39,40,42,45,48,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260714 a 00</strong> UTC HH+180 (rango:168-192)<br>grupo: <strong>2</strong> representante: <strong>15</strong> miembros: 23 <br>3,6,7,8,9,10,13,14,15,21,22,23,24,27,32,36,37,38,41,43,44,46,47';}
}
